Changelog
=========

v1.1.3
------

- Improve exception output on failing to infer file type
- `dr-compare`: Fix bug in calling `list|all` command

v1.1.2
------

- Add Python 3.9 support
- Use Black for code formatting
- Miscellaneous developer tooling updates

v1.1.1
------

- Added instructions for disabling TLS validation on Windows
- Linter fixes & tweaks to configuration
- Minor documentation updates

v1.1.0
------

- Support for custom API endpoints (API Self-hosted & regional clouds)
- Numerous improvements, fixes, & tweaks (see commit history)
